@@ -26,8 +26,7 @@ from .compound import (Compound,
                        Linear,
                        Location,
                        Relation)
-from .geometry import (Coordinate,
-                       Geometry)
+from .geometry import Geometry
 from .iterable import non_negative_min
 from .multipoint import Multipoint
 from .packing import pack_mix
@@ -40,7 +39,7 @@ from .utils import (relate_multipoint_to_linear_compound,
 MIN_MULTISEGMENT_SEGMENTS_COUNT = 2
 
 
-class Multisegment(Indexable[Coordinate], Linear[Coordinate]):
+class Multisegment(Indexable[Scalar], Linear[Scalar]):
     __slots__ = ('_locate', '_point_nearest_segment',
                  '_segment_nearest_segment', '_segments', '_segments_set')
 
@@ -62,11 +61,12 @@ class Multisegment(Indexable[Coordinate], Linear[Coordinate]):
                                context=context)
         self._point_nearest_segment, self._segment_nearest_segment = (
             partial(to_point_nearest_segment, context, segments),
-            partial(to_segment_nearest_segment, context, segments))
+            partial(to_segment_nearest_segment, context, segments)
+        )
 
     __repr__ = generate_repr(__init__)
 
-    def __and__(self, other: Compound[Coordinate]) -> Compound[Coordinate]:
+    def __and__(self, other: Compound[Scalar]) -> Compound[Scalar]:
         """
         Returns intersection of the multisegment with the other geometry.
 
@@ -83,18 +83,20 @@ class Multisegment(Indexable[Coordinate], Linear[Coordinate]):
         >>> multisegment & multisegment == multisegment
         True
         """
-        return (complete_intersect_segment_with_multisegment(
-                other, self,
-                context=self._context)
-                if isinstance(other, Segment)
-                else (complete_intersect_multisegments(self, other,
-                                                       context=self._context)
-                      if isinstance(other, Multisegment)
-                      else NotImplemented))
+        if isinstance(other, Segment):
+            return complete_intersect_segment_with_multisegment(
+                    other, self,
+                    context=self._context
+            )
+        else:
+            return (complete_intersect_multisegments(self, other,
+                                                     context=self._context)
+                    if isinstance(other, Multisegment)
+                    else NotImplemented)
 
     __rand__ = __and__
 
-    def __contains__(self, point: Point[Coordinate]) -> bool:
+    def __contains__(self, point: Point[Scalar]) -> bool:
         """
         Checks if the multisegment contains the point.
 
@@ -115,7 +117,7 @@ class Multisegment(Indexable[Coordinate], Linear[Coordinate]):
         """
         return bool(self.locate(point))
 
-    def __eq__(self, other: 'Multisegment[Coordinate]') -> bool:
+    def __eq__(self, other: 'Multisegment[Scalar]') -> bool:
         """
         Checks if multisegments are equal.
 
@@ -141,7 +143,7 @@ class Multisegment(Indexable[Coordinate], Linear[Coordinate]):
                                  if isinstance(other, Multisegment)
                                  else NotImplemented)
 
-    def __ge__(self, other: Compound[Coordinate]) -> bool:
+    def __ge__(self, other: Compound[Scalar]) -> bool:
         """
         Checks if the multisegment is a superset of the other geometry.
 
@@ -176,7 +178,7 @@ class Multisegment(Indexable[Coordinate], Linear[Coordinate]):
                     if isinstance(other, Compound)
                     else NotImplemented))
 
-    def __gt__(self, other: Compound[Coordinate]) -> bool:
+    def __gt__(self, other: Compound[Scalar]) -> bool:
         """
         Checks if the multisegment is a strict superset of the other geometry.
 
@@ -228,7 +230,7 @@ class Multisegment(Indexable[Coordinate], Linear[Coordinate]):
         """
         return hash(self._segments_set)
 
-    def __le__(self, other: Compound[Coordinate]) -> bool:
+    def __le__(self, other: Compound[Scalar]) -> bool:
         """
         Checks if the multisegment is a subset of the other geometry.
 
@@ -258,7 +260,7 @@ class Multisegment(Indexable[Coordinate], Linear[Coordinate]):
                      if isinstance(other, Linear)
                      else NotImplemented))
 
-    def __lt__(self, other: Compound[Coordinate]) -> bool:
+    def __lt__(self, other: Compound[Scalar]) -> bool:
         """
         Checks if the multisegment is a strict subset of the other geometry.
 
@@ -288,7 +290,7 @@ class Multisegment(Indexable[Coordinate], Linear[Coordinate]):
                      if isinstance(other, Linear)
                      else NotImplemented))
 
-    def __or__(self, other: Compound[Coordinate]) -> Compound[Coordinate]:
+    def __or__(self, other: Compound[Scalar]) -> Compound[Scalar]:
         """
         Returns union of the multisegment with the other geometry.
 
@@ -317,7 +319,7 @@ class Multisegment(Indexable[Coordinate], Linear[Coordinate]):
 
     __ror__ = __or__
 
-    def __rsub__(self, other: Compound[Coordinate]) -> Compound[Coordinate]:
+    def __rsub__(self, other: Compound[Scalar]) -> Compound[Scalar]:
         """
         Returns difference of the other geometry with the multisegment.
 
@@ -333,7 +335,7 @@ class Multisegment(Indexable[Coordinate], Linear[Coordinate]):
                 if isinstance(other, Segment)
                 else NotImplemented)
 
-    def __sub__(self, other: Compound[Coordinate]) -> Compound[Coordinate]:
+    def __sub__(self, other: Compound[Scalar]) -> Compound[Scalar]:
         """
         Returns difference of the multisegment with the other geometry.
 
@@ -360,7 +362,7 @@ class Multisegment(Indexable[Coordinate], Linear[Coordinate]):
                             if isinstance(other, Multisegment)
                             else NotImplemented)))
 
-    def __xor__(self, other: Compound[Coordinate]) -> Compound[Coordinate]:
+    def __xor__(self, other: Compound[Scalar]) -> Compound[Scalar]:
         """
         Returns symmetric difference of the multisegment
         with the other geometry.
@@ -378,17 +380,18 @@ class Multisegment(Indexable[Coordinate], Linear[Coordinate]):
         >>> multisegment ^ multisegment is EMPTY
         True
         """
-        return (self._unite_with_multipoint(other)
-                if isinstance(other, Multipoint)
-                else
-                (symmetric_subtract_multisegment_from_segment(
-                        other, self,
-                        context=self._context)
-                 if isinstance(other, Segment)
-                 else (symmetric_subtract_multisegments(self, other,
-                                                        context=self._context)
-                       if isinstance(other, Multisegment)
-                       else NotImplemented)))
+        if isinstance(other, Multipoint):
+            return self._unite_with_multipoint(other)
+        elif isinstance(other, Segment):
+            return symmetric_subtract_multisegment_from_segment(
+                    other, self,
+                    context=self._context
+            )
+        else:
+            return (symmetric_subtract_multisegments(self, other,
+                                                     context=self._context)
+                    if isinstance(other, Multisegment)
+                    else NotImplemented)
 
     __rxor__ = __xor__
 
@@ -429,7 +432,7 @@ class Multisegment(Indexable[Coordinate], Linear[Coordinate]):
         return self._context.multisegment_length(self)
 
     @property
-    def segments(self) -> Sequence[Segment[Coordinate]]:
+    def segments(self) -> Sequence[Segment[Scalar]]:
         """
         Returns segments of the multisegment.
 
@@ -449,7 +452,7 @@ class Multisegment(Indexable[Coordinate], Linear[Coordinate]):
         """
         return list(self._segments)
 
-    def distance_to(self, other: Geometry[Coordinate]) -> Scalar:
+    def distance_to(self, other: Geometry[Scalar]) -> Scalar:
         """
         Returns distance between the multisegment and the other geometry.
 
@@ -501,7 +504,7 @@ class Multisegment(Indexable[Coordinate], Linear[Coordinate]):
         self._point_nearest_segment = tree.nearest_to_point_segment
         self._segment_nearest_segment = tree.nearest_segment
 
-    def locate(self, point: Point[Coordinate]) -> Location:
+    def locate(self, point: Point[Scalar]) -> Location:
         """
         Finds location of the point relative to the multisegment.
 
@@ -524,7 +527,7 @@ class Multisegment(Indexable[Coordinate], Linear[Coordinate]):
         """
         return self._locate(point)
 
-    def relate(self, other: Compound[Coordinate]) -> Relation:
+    def relate(self, other: Compound[Scalar]) -> Relation:
         """
         Finds relation between the multisegment and the other geometry.
 
@@ -551,8 +554,8 @@ class Multisegment(Indexable[Coordinate], Linear[Coordinate]):
 
     def rotate(self,
                angle: Angle,
-               point: Optional[Point[Coordinate]] = None
-               ) -> 'Multisegment[Coordinate]':
+               point: Optional[Point[Scalar]] = None
+               ) -> 'Multisegment[Scalar]':
         """
         Rotates the multisegment by given angle around given point.
 
@@ -573,15 +576,17 @@ class Multisegment(Indexable[Coordinate], Linear[Coordinate]):
         ...                   Segment(Point(1, 0), Point(1, 1))]))
         True
         """
-        return (self._context.rotate_multisegment_around_origin(
-                self, angle.cosine, angle.sine)
-                if point is None
-                else self._context.rotate_multisegment(self, angle.cosine,
-                                                       angle.sine, point))
+        if point is None:
+            return self._context.rotate_multisegment_around_origin(
+                    self, angle.cosine, angle.sine
+            )
+        else:
+            return self._context.rotate_multisegment(self, angle.cosine,
+                                                     angle.sine, point)
 
     def scale(self,
-              factor_x: Coordinate,
-              factor_y: Optional[Coordinate] = None) -> Compound[Coordinate]:
+              factor_x: Scalar,
+              factor_y: Optional[Scalar] = None) -> Compound[Scalar]:
         """
         Scales the multisegment by given factor.
 
@@ -603,11 +608,12 @@ class Multisegment(Indexable[Coordinate], Linear[Coordinate]):
         True
         """
         return self._context.scale_multisegment(
-                self, factor_x, factor_x if factor_y is None else factor_y)
+                self, factor_x, factor_x if factor_y is None else factor_y
+        )
 
     def translate(self,
-                  step_x: Coordinate,
-                  step_y: Coordinate) -> 'Multisegment[Coordinate]':
+                  step_x: Scalar,
+                  step_y: Scalar) -> 'Multisegment[Scalar]':
         """
         Translates the multisegment by given step.
 
@@ -659,15 +665,17 @@ class Multisegment(Indexable[Coordinate], Linear[Coordinate]):
                                      context=self._context):
             raise ValueError('Crossing or overlapping segments found.')
 
-    def _distance_to_point(self, other: Point[Coordinate]) -> Scalar:
+    def _distance_to_point(self, other: Point[Scalar]) -> Scalar:
         return self._context.sqrt(self._context.segment_point_squared_distance(
-                self._point_nearest_segment(other), other))
+                self._point_nearest_segment(other), other
+        ))
 
-    def _distance_to_segment(self, other: Segment[Coordinate]) -> Scalar:
+    def _distance_to_segment(self, other: Segment[Scalar]) -> Scalar:
         return self._context.sqrt(self._context.segments_squared_distance(
-                self._segment_nearest_segment(other), other))
+                self._segment_nearest_segment(other), other
+        ))
 
-    def _unite_with_multipoint(self, other: Multipoint[Coordinate]
-                               ) -> Compound[Coordinate]:
+    def _unite_with_multipoint(self, other: Multipoint[Scalar]
+                               ) -> Compound[Scalar]:
         return pack_mix(other - self, self, self._context.empty,
                         self._context.empty, self._context.mix_cls)
